@@ -32,7 +32,7 @@ public:
     QSet<Solid::DeviceInterface::Type> supportedInterfaces() const override;
     QStringList allDevices() override;
     QStringList devicesFromQuery(const QString &parentUdi, Solid::DeviceInterface::Type type) override;
-    QObject *createDevice(const QString &udi) override;
+    std::unique_ptr<QObject> createDevice(const QString &udi) override;
 
 Q_SIGNALS:
     void mtabChanged(const QString &device);
